@@ -88,7 +88,7 @@ class hmath_setting:
         HDD_save_time = 60
         def HDD_save_reset():
             memo_plk = open("%smemo.plk" %directory, "w", encoding='UTF-8')
-            memo_plk.write(str(dumps({"B":{},"ln":{},"rad":{},"exp":{},"sin":{},"cos":{},"tan":{},"csc":{},"sec":{},"cot":{},"log":{},"log2":{},"zeta":{},"asin":{},"acos":{},"atan":{},"acsc":{},"asec":{},"acot":{},"sinh":{},"cosh":{},"tanh":{},"csch":{},"sech":{},"coth":{},"cube":{},"sqrt":{},"log10":{},"asinh":{},"acosh":{},"atanh":{},"acsch":{},"asech":{},"acoth":{},"Gamma":{},"diganma":{},"radical":{},"factorial":{},"reduct_fract":{},"prime_test":{},"prime_fact":{}})))
+            memo_plk.write(str(dumps({"sign":{},"B":{},"ln":{},"rad":{},"exp":{},"sin":{},"cos":{},"tan":{},"csc":{},"sec":{},"cot":{},"log":{},"log2":{},"zeta":{},"asin":{},"acos":{},"atan":{},"acsc":{},"asec":{},"acot":{},"sinh":{},"cosh":{},"tanh":{},"csch":{},"sech":{},"coth":{},"cube":{},"sqrt":{},"log10":{},"asinh":{},"acosh":{},"atanh":{},"acsch":{},"asech":{},"acoth":{},"Gamma":{},"diganma":{},"radical":{},"factorial":{},"reduct_fract":{},"prime_test":{},"prime_fact":{}})))
             memo_plk.close()
     class fract:
         max_about_minute_limit : int = 40
@@ -722,7 +722,6 @@ def lcm(*args) -> int or array:
 def sign(x):
     return x / -x
 
-@__memo
 def theta(x):
     if 0 < x:
         return 1
@@ -1281,6 +1280,6 @@ try:
     __corresponding_dictionary = load(memo_plk)
     memo_plk.close()
 except:
-    __corresponding_dictionary = {"B":{},"ln":{},"rad":{},"exp":{},"sin":{},"cos":{},"tan":{},"csc":{},"sec":{},"cot":{},"log":{},"log2":{},"zeta":{},"asin":{},"acos":{},"atan":{},"acsc":{},"asec":{},"acot":{},"sinh":{},"cosh":{},"tanh":{},"csch":{},"sech":{},"coth":{},"cube":{},"sqrt":{},"log10":{},"asinh":{},"acosh":{},"atanh":{},"acsch":{},"asech":{},"acoth":{},"Gamma":{},"diganma":{},"radical":{},"factorial":{},"reduct_fract":{},"prime_test":{},"prime_fact":{}}
+    __corresponding_dictionary = {"sign":{},"B":{},"ln":{},"rad":{},"exp":{},"sin":{},"cos":{},"tan":{},"csc":{},"sec":{},"cot":{},"log":{},"log2":{},"zeta":{},"asin":{},"acos":{},"atan":{},"acsc":{},"asec":{},"acot":{},"sinh":{},"cosh":{},"tanh":{},"csch":{},"sech":{},"coth":{},"cube":{},"sqrt":{},"log10":{},"asinh":{},"acosh":{},"atanh":{},"acsch":{},"asech":{},"acoth":{},"Gamma":{},"diganma":{},"radical":{},"factorial":{},"reduct_fract":{},"prime_test":{},"prime_fact":{}}
 
 directory = f"P:\python\hmath\packaging_tutorial\hmath\hmath"
\ No newline at end of file
